CHANGELOG
---------------------------------------
### 2025-06-30 - Official release 1.0.0
* base IRI changed to https://model.ccmm.cz/research-data/
* definitions and usage notes updated and synced for the best possible understanding of end-users
* fixed minor issues 
* enhanced support for spatial representations 
* support for both date and date time 
* JSON schema is not supported at the time due to the technical issues


### 2025-05-20 - Major release
* probably last publication before official release
* compact use of indentifiers and agents
* codelists as separate classes
* detailed attributes for address (according to INSPIRE core location ontology)
* minor bug fixes

### 2025-04-24 - Bug fixes
* bugs forcing users to edit XSD partially fixed

### 2025-04-22 - Major release
* XSDs generated from DataSpecer
* Specification and artifacts generated from Dataspecer https://github.com/mff-uk/dataspecer/commit/51d46a9d87ab5e5258299e548664b7d97a51dc51
* resolving issues regarding MD content
* CCMM profiled newly from CCMM vocabulary (available from here: https://EOSC-CZ.github.io/CCMM-V/en/model.owl.ttl)

### 2025-04-03 - Minor changes
* resolving GH issues
* minor changes in content

### 2025-03-19 - Minor changes
* Changes in data and structures in order to fulfil requirements of Invenio
* Manual changes in XSDs 

### 2025-03-08 - Initial release
* Imported CCMM specification with XSD artifacts generated from DataSpecer 
